<?php

class VC_REDO
{
    private $file;

    function __construct($file)
    {
        $this->file = $file;
        add_action('init', array($this, 'check_for_install'));
        add_action('vc_before_init', array($this, 'vc_redo_widgets'));
        add_action('wp_ajax_vc_save_data', array($this, 'vc_redo_update'));
        
    }

    public function redo_init()
    {
        register_activation_hook($this->file, array($this, 'redo_activation'));
    }

    function vc_redo_widgets()
    {
        include 'widgets/projekty.php';
        include 'widgets/customPostRedo.php';
    }

    function vc_redo_update()
    {
        if (isset($_REQUEST)) {
            update_option('redo_activation', $_REQUEST);
        }
    }
    
    function check_for_install()
    {
        if (!defined('CPT_VERSION') || !defined('ACF_VERSION') || !defined('WPB_VC_VERSION')) {
            add_action('admin_notices', array( $this,'show_redo_warning'));
            return;
        }
    }

    private static function parseCustomFields($fieldList, &$fields, $group){
        foreach($fieldList as $field){
            $fields[$group]["fields"][$field["name"]]["value"] = $field["name"];
        }
    }

    public static function prepareCustomFields()
    {
        if(defined('ACF_VERSION')){
        /*
         * Pobierz listę stworzonych grup
         */
        $groups = acf_get_raw_field_groups();
        //VC_REDO::debug($groups, true);
        $fields = array();
        /**
         * przygotuj liste pol sortowane po grupach
         */
        foreach($groups as $group){
            
            $fields[$group["ID"]]["title"] = $group["title"];
            $field_list = acf_get_fields($group["ID"]);
            self::parseCustomFields($field_list, $fields, $group["ID"]);
        }
        }
        return $fields;
    }

    public function redo_activation()
    {
        if (!get_option('vc_redo_update')) {
            $vc_default_options = array(
                'projekty' => 'on',
                'customPostRedo' => 'on',
            );
            update_option('vc_redo_update', $vc_default_options);
        }
    }

    public static function ifLoggedAdmin()
    {
        $current_user = wp_get_current_user();
        if (user_can($current_user, 'administrator')) {
            return true;
        }
        return false;
    }

    public static function debug($var, $die = false)
    {
        if (VC_REDO::ifLoggedAdmin()) {
            echo "<pre>";
            print_r($var);
            echo "</pre>";
            if ($die) die();
        }
    }

    function show_redo_warning()
    {
        if (!defined('WPB_VC_VERSION')) {
            $link = "https://wpbakery.com/";
            $plugin = "WPBakery Page Builder";
            ?>
        <div class="notice notice-warning is-dismissible">
            <p>Please install <a href="<?php echo $link; ?>"><?php echo $plugin; ?></a> to use REDO JSComposer
                Additional.</p>
        </div>
        <?php
        }
        if (!defined('CPT_VERSION')) {
            $link = "https://pl.wordpress.org/plugins/custom-post-type-ui/";
            $plugin = "Custom Post Type UI";
            ?>
        <div class="notice notice-warning is-dismissible">
            <p>Please install <a href="<?php echo $link; ?>"><?php echo $plugin; ?></a> to use REDO JSComposer
                Additional.</p>
        </div>
        <?php
        }
        if (!defined('ACF_VERSION')) {
            $link = "https://pl.wordpress.org/plugins/advanced-custom-fields/";
            $plugin = "Advanced Custom Fields";
            ?>
        <div class="notice notice-warning is-dismissible">
            <p>Please install <a href="<?php echo $link; ?>"><?php echo $plugin; ?></a> to use REDO JSComposer
                Additional.</p>
        </div>
        <?php
        }
        
    }
}

?>